@@ -10,7 +10,7 @@ pub mod root {
     pub mod bar {
         #[allow(unused_imports)]
         use self::super::super::root;
-        extern "C" {
+        unsafe extern "C" {
             #[link_name = "\u{1}_ZN3bar18NamespacedFunctionEv"]
             pub fn NamespacedFunction();
         }
@@ -20,17 +20,9 @@ pub mod root {
     pub struct C {
         pub _address: u8,
     }
-    #[test]
-    fn bindgen_test_layout_C() {
-        assert_eq!(
-            ::std::mem::size_of::<C>(),
-            1usize,
-            concat!("Size of: ", stringify!(C)),
-        );
-        assert_eq!(
-            ::std::mem::align_of::<C>(),
-            1usize,
-            concat!("Alignment of ", stringify!(C)),
-        );
-    }
+    #[allow(clippy::unnecessary_operation, clippy::identity_op)]
+    const _: () = {
+        ["Size of C"][::std::mem::size_of::<C>() - 1usize];
+        ["Alignment of C"][::std::mem::align_of::<C>() - 1usize];
+    };
 }
