@@ -39,21 +39,17 @@ pub struct C {
 fn bindgen_test_layout_C() {
     const UNINIT: ::std::mem::MaybeUninit<C> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(::std::mem::size_of::<C>(), 40usize, concat!("Size of: ", stringify!(C)));
-    assert_eq!(
-        ::std::mem::align_of::<C>(),
-        4usize,
-        concat!("Alignment of ", stringify!(C)),
-    );
+    assert_eq!(::std::mem::size_of::<C>(), 40usize, "Size of C");
+    assert_eq!(::std::mem::align_of::<C>(), 4usize, "Alignment of C");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(C), "::", stringify!(a)),
+        "Offset of field: C::a",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).big_array) as usize - ptr as usize },
         4usize,
-        concat!("Offset of field: ", stringify!(C), "::", stringify!(big_array)),
+        "Offset of field: C::big_array",
     );
 }
 impl Default for C {
@@ -78,44 +74,29 @@ fn bindgen_test_layout_C_with_zero_length_array() {
     assert_eq!(
         ::std::mem::size_of::<C_with_zero_length_array>(),
         40usize,
-        concat!("Size of: ", stringify!(C_with_zero_length_array)),
+        "Size of C_with_zero_length_array",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_zero_length_array>(),
         4usize,
-        concat!("Alignment of ", stringify!(C_with_zero_length_array)),
+        "Alignment of C_with_zero_length_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_zero_length_array::a",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).big_array) as usize - ptr as usize },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array),
-            "::",
-            stringify!(big_array),
-        ),
+        "Offset of field: C_with_zero_length_array::big_array",
     );
     assert_eq!(
         unsafe {
             ::std::ptr::addr_of!((*ptr).zero_length_array) as usize - ptr as usize
         },
         37usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array),
-            "::",
-            stringify!(zero_length_array),
-        ),
+        "Offset of field: C_with_zero_length_array::zero_length_array",
     );
 }
 impl Default for C_with_zero_length_array {
@@ -140,34 +121,24 @@ fn bindgen_test_layout_C_with_zero_length_array_2() {
     assert_eq!(
         ::std::mem::size_of::<C_with_zero_length_array_2>(),
         4usize,
-        concat!("Size of: ", stringify!(C_with_zero_length_array_2)),
+        "Size of C_with_zero_length_array_2",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_zero_length_array_2>(),
         4usize,
-        concat!("Alignment of ", stringify!(C_with_zero_length_array_2)),
+        "Alignment of C_with_zero_length_array_2",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_2),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_zero_length_array_2::a",
     );
     assert_eq!(
         unsafe {
             ::std::ptr::addr_of!((*ptr).zero_length_array) as usize - ptr as usize
         },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_2),
-            "::",
-            stringify!(zero_length_array),
-        ),
+        "Offset of field: C_with_zero_length_array_2::zero_length_array",
     );
 }
 #[repr(C)]
@@ -183,42 +154,27 @@ fn bindgen_test_layout_C_with_incomplete_array() {
     assert_eq!(
         ::std::mem::size_of::<C_with_incomplete_array>(),
         40usize,
-        concat!("Size of: ", stringify!(C_with_incomplete_array)),
+        "Size of C_with_incomplete_array",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_incomplete_array>(),
         4usize,
-        concat!("Alignment of ", stringify!(C_with_incomplete_array)),
+        "Alignment of C_with_incomplete_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_incomplete_array),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_incomplete_array::a",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).big_array) as usize - ptr as usize },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_incomplete_array),
-            "::",
-            stringify!(big_array),
-        ),
+        "Offset of field: C_with_incomplete_array::big_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).incomplete_array) as usize - ptr as usize },
         37usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_incomplete_array),
-            "::",
-            stringify!(incomplete_array),
-        ),
+        "Offset of field: C_with_incomplete_array::incomplete_array",
     );
 }
 impl Default for C_with_incomplete_array {
@@ -243,32 +199,22 @@ fn bindgen_test_layout_C_with_incomplete_array_2() {
     assert_eq!(
         ::std::mem::size_of::<C_with_incomplete_array_2>(),
         4usize,
-        concat!("Size of: ", stringify!(C_with_incomplete_array_2)),
+        "Size of C_with_incomplete_array_2",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_incomplete_array_2>(),
         4usize,
-        concat!("Alignment of ", stringify!(C_with_incomplete_array_2)),
+        "Alignment of C_with_incomplete_array_2",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_incomplete_array_2),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_incomplete_array_2::a",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).incomplete_array) as usize - ptr as usize },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_incomplete_array_2),
-            "::",
-            stringify!(incomplete_array),
-        ),
+        "Offset of field: C_with_incomplete_array_2::incomplete_array",
     );
 }
 #[repr(C)]
@@ -287,57 +233,34 @@ fn bindgen_test_layout_C_with_zero_length_array_and_incomplete_array() {
     assert_eq!(
         ::std::mem::size_of::<C_with_zero_length_array_and_incomplete_array>(),
         40usize,
-        concat!("Size of: ", stringify!(C_with_zero_length_array_and_incomplete_array)),
+        "Size of C_with_zero_length_array_and_incomplete_array",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_zero_length_array_and_incomplete_array>(),
         4usize,
-        concat!(
-            "Alignment of ",
-            stringify!(C_with_zero_length_array_and_incomplete_array),
-        ),
+        "Alignment of C_with_zero_length_array_and_incomplete_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array::a",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).big_array) as usize - ptr as usize },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array),
-            "::",
-            stringify!(big_array),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array::big_array",
     );
     assert_eq!(
         unsafe {
             ::std::ptr::addr_of!((*ptr).zero_length_array) as usize - ptr as usize
         },
         37usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array),
-            "::",
-            stringify!(zero_length_array),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array::zero_length_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).incomplete_array) as usize - ptr as usize },
         37usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array),
-            "::",
-            stringify!(incomplete_array),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array::incomplete_array",
     );
 }
 impl Default for C_with_zero_length_array_and_incomplete_array {
@@ -365,47 +288,29 @@ fn bindgen_test_layout_C_with_zero_length_array_and_incomplete_array_2() {
     assert_eq!(
         ::std::mem::size_of::<C_with_zero_length_array_and_incomplete_array_2>(),
         4usize,
-        concat!("Size of: ", stringify!(C_with_zero_length_array_and_incomplete_array_2)),
+        "Size of C_with_zero_length_array_and_incomplete_array_2",
     );
     assert_eq!(
         ::std::mem::align_of::<C_with_zero_length_array_and_incomplete_array_2>(),
         4usize,
-        concat!(
-            "Alignment of ",
-            stringify!(C_with_zero_length_array_and_incomplete_array_2),
-        ),
+        "Alignment of C_with_zero_length_array_and_incomplete_array_2",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).a) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array_2),
-            "::",
-            stringify!(a),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array_2::a",
     );
     assert_eq!(
         unsafe {
             ::std::ptr::addr_of!((*ptr).zero_length_array) as usize - ptr as usize
         },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array_2),
-            "::",
-            stringify!(zero_length_array),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array_2::zero_length_array",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).incomplete_array) as usize - ptr as usize },
         4usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(C_with_zero_length_array_and_incomplete_array_2),
-            "::",
-            stringify!(incomplete_array),
-        ),
+        "Offset of field: C_with_zero_length_array_and_incomplete_array_2::incomplete_array",
     );
 }
 #[repr(C)]
@@ -417,20 +322,12 @@ pub struct WithDtor {
 fn bindgen_test_layout_WithDtor() {
     const UNINIT: ::std::mem::MaybeUninit<WithDtor> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(
-        ::std::mem::size_of::<WithDtor>(),
-        4usize,
-        concat!("Size of: ", stringify!(WithDtor)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<WithDtor>(),
-        4usize,
-        concat!("Alignment of ", stringify!(WithDtor)),
-    );
+    assert_eq!(::std::mem::size_of::<WithDtor>(), 4usize, "Size of WithDtor");
+    assert_eq!(::std::mem::align_of::<WithDtor>(), 4usize, "Alignment of WithDtor");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).b) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(WithDtor), "::", stringify!(b)),
+        "Offset of field: WithDtor::b",
     );
 }
 #[repr(C)]
@@ -445,32 +342,22 @@ fn bindgen_test_layout_IncompleteArrayNonCopiable() {
     assert_eq!(
         ::std::mem::size_of::<IncompleteArrayNonCopiable>(),
         8usize,
-        concat!("Size of: ", stringify!(IncompleteArrayNonCopiable)),
+        "Size of IncompleteArrayNonCopiable",
     );
     assert_eq!(
         ::std::mem::align_of::<IncompleteArrayNonCopiable>(),
         8usize,
-        concat!("Alignment of ", stringify!(IncompleteArrayNonCopiable)),
+        "Alignment of IncompleteArrayNonCopiable",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).whatever) as usize - ptr as usize },
         0usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(IncompleteArrayNonCopiable),
-            "::",
-            stringify!(whatever),
-        ),
+        "Offset of field: IncompleteArrayNonCopiable::whatever",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).incomplete_array) as usize - ptr as usize },
         8usize,
-        concat!(
-            "Offset of field: ",
-            stringify!(IncompleteArrayNonCopiable),
-            "::",
-            stringify!(incomplete_array),
-        ),
+        "Offset of field: IncompleteArrayNonCopiable::incomplete_array",
     );
 }
 impl Default for IncompleteArrayNonCopiable {
@@ -492,25 +379,17 @@ pub union Union {
 fn bindgen_test_layout_Union() {
     const UNINIT: ::std::mem::MaybeUninit<Union> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(
-        ::std::mem::size_of::<Union>(),
-        4usize,
-        concat!("Size of: ", stringify!(Union)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<Union>(),
-        4usize,
-        concat!("Alignment of ", stringify!(Union)),
-    );
+    assert_eq!(::std::mem::size_of::<Union>(), 4usize, "Size of Union");
+    assert_eq!(::std::mem::align_of::<Union>(), 4usize, "Alignment of Union");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).d) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(Union), "::", stringify!(d)),
+        "Offset of field: Union::d",
     );
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).i) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(Union), "::", stringify!(i)),
+        "Offset of field: Union::i",
     );
 }
 impl Default for Union {
@@ -531,20 +410,12 @@ pub struct WithUnion {
 fn bindgen_test_layout_WithUnion() {
     const UNINIT: ::std::mem::MaybeUninit<WithUnion> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(
-        ::std::mem::size_of::<WithUnion>(),
-        4usize,
-        concat!("Size of: ", stringify!(WithUnion)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<WithUnion>(),
-        4usize,
-        concat!("Alignment of ", stringify!(WithUnion)),
-    );
+    assert_eq!(::std::mem::size_of::<WithUnion>(), 4usize, "Size of WithUnion");
+    assert_eq!(::std::mem::align_of::<WithUnion>(), 4usize, "Alignment of WithUnion");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).data) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(WithUnion), "::", stringify!(data)),
+        "Offset of field: WithUnion::data",
     );
 }
 impl Default for WithUnion {
@@ -566,12 +437,12 @@ fn bindgen_test_layout_RealAbstractionWithTonsOfMethods() {
     assert_eq!(
         ::std::mem::size_of::<RealAbstractionWithTonsOfMethods>(),
         1usize,
-        concat!("Size of: ", stringify!(RealAbstractionWithTonsOfMethods)),
+        "Size of RealAbstractionWithTonsOfMethods",
     );
     assert_eq!(
         ::std::mem::align_of::<RealAbstractionWithTonsOfMethods>(),
         1usize,
-        concat!("Alignment of ", stringify!(RealAbstractionWithTonsOfMethods)),
+        "Alignment of RealAbstractionWithTonsOfMethods",
     );
 }
 extern "C" {
