@@ -12,26 +12,14 @@ pub use self::foo_alias1 as foo_alias2;
 pub struct bar {
     pub this_should_work: foo::Type,
 }
-#[test]
-fn bindgen_test_layout_bar() {
-    const UNINIT: ::std::mem::MaybeUninit<bar> = ::std::mem::MaybeUninit::uninit();
-    let ptr = UNINIT.as_ptr();
-    assert_eq!(
-        ::std::mem::size_of::<bar>(),
-        4usize,
-        concat!("Size of: ", stringify!(bar)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<bar>(),
-        4usize,
-        concat!("Alignment of ", stringify!(bar)),
-    );
-    assert_eq!(
-        unsafe { ::std::ptr::addr_of!((*ptr).this_should_work) as usize - ptr as usize },
-        0usize,
-        concat!("Offset of field: ", stringify!(bar), "::", stringify!(this_should_work)),
-    );
-}
+#[allow(clippy::unnecessary_operation, clippy::identity_op)]
+const _: () = {
+    ["Size of bar"][::std::mem::size_of::<bar>() - 4usize];
+    ["Alignment of bar"][::std::mem::align_of::<bar>() - 4usize];
+    [
+        "Offset of field: bar::this_should_work",
+    ][::std::mem::offset_of!(bar, this_should_work) - 0usize];
+};
 impl Default for bar {
     fn default() -> Self {
         let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
@@ -41,14 +29,14 @@ impl Default for bar {
         }
     }
 }
-extern "C" {
+unsafe extern "C" {
     pub fn func1(
         arg1: foo::Type,
         arg2: *mut foo::Type,
         arg3: *mut *mut foo::Type,
     ) -> *mut foo::Type;
 }
-extern "C" {
+unsafe extern "C" {
     pub fn func2(
         arg1: foo_alias1,
         arg2: *mut foo_alias1,
