@@ -8,20 +8,12 @@ pub struct nsFoo {
 fn bindgen_test_layout_nsFoo() {
     const UNINIT: ::std::mem::MaybeUninit<nsFoo> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(
-        ::std::mem::size_of::<nsFoo>(),
-        1600usize,
-        concat!("Size of: ", stringify!(nsFoo)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<nsFoo>(),
-        4usize,
-        concat!("Alignment of ", stringify!(nsFoo)),
-    );
+    assert_eq!(::std::mem::size_of::<nsFoo>(), 1600usize, "Size of nsFoo");
+    assert_eq!(::std::mem::align_of::<nsFoo>(), 4usize, "Alignment of nsFoo");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).details) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(nsFoo), "::", stringify!(details)),
+        "Offset of field: nsFoo::details",
     );
 }
 impl Default for nsFoo {
