@@ -1,5 +1,5 @@
 #![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
-extern "C" {
+unsafe extern "C" {
     pub static mut foo: ::std::option::Option<
         unsafe extern "C" fn(
             x: ::std::os::raw::c_int,
