@@ -1,4 +1,4 @@
 #![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
-extern "C" {
+unsafe extern "C" {
     pub fn f(x: *mut ::std::os::raw::c_int);
 }
