@@ -6,12 +6,12 @@ pub mod root {
     pub mod ns {
         #[allow(unused_imports)]
         use self::super::super::root;
-        pub const AB_A: root::ns::AB = 0;
-        pub const AB_B: root::ns::AB = 1;
+        pub const AB_A: AB = 0;
+        pub const AB_B: AB = 1;
         pub type AB = ::std::os::raw::c_int;
     }
     pub use self::super::root::ns::AB as AB;
-    extern "C" {
+    unsafe extern "C" {
         #[link_name = "\u{1}_ZL2kA"]
         pub static kA: root::AB;
     }
