@@ -4,22 +4,12 @@
 pub struct S {
     pub large_array: [::std::os::raw::c_char; 33usize],
 }
-#[test]
-fn bindgen_test_layout_S() {
-    const UNINIT: ::std::mem::MaybeUninit<S> = ::std::mem::MaybeUninit::uninit();
-    let ptr = UNINIT.as_ptr();
-    assert_eq!(::std::mem::size_of::<S>(), 33usize, concat!("Size of: ", stringify!(S)));
-    assert_eq!(
-        ::std::mem::align_of::<S>(),
-        1usize,
-        concat!("Alignment of ", stringify!(S)),
-    );
-    assert_eq!(
-        unsafe { ::std::ptr::addr_of!((*ptr).large_array) as usize - ptr as usize },
-        0usize,
-        concat!("Offset of field: ", stringify!(S), "::", stringify!(large_array)),
-    );
-}
+#[allow(clippy::unnecessary_operation, clippy::identity_op)]
+const _: () = {
+    ["Size of S"][::std::mem::size_of::<S>() - 33usize];
+    ["Alignment of S"][::std::mem::align_of::<S>() - 1usize];
+    ["Offset of field: S::large_array"][::std::mem::offset_of!(S, large_array) - 0usize];
+};
 impl Default for S {
     fn default() -> Self {
         let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
@@ -32,8 +22,8 @@ impl Default for S {
 #[repr(C)]
 #[derive(Debug, Hash, PartialEq, Eq)]
 pub struct ST<T> {
-    pub large_array: [T; 33usize],
     pub _phantom_0: ::std::marker::PhantomData<::std::cell::UnsafeCell<T>>,
+    pub large_array: [T; 33usize],
 }
 impl<T> Default for ST<T> {
     fn default() -> Self {
