@@ -1,5 +1,5 @@
 #![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
 pub const MODBUS_WOOT: u32 = 3;
-extern "C" {
+unsafe extern "C" {
     pub fn foo();
 }
