@@ -8,17 +8,9 @@ pub mod root {
     pub struct Test {
         pub _address: u8,
     }
-    #[test]
-    fn bindgen_test_layout_Test() {
-        assert_eq!(
-            ::std::mem::size_of::<Test>(),
-            1usize,
-            concat!("Size of: ", stringify!(Test)),
-        );
-        assert_eq!(
-            ::std::mem::align_of::<Test>(),
-            1usize,
-            concat!("Alignment of ", stringify!(Test)),
-        );
-    }
+    #[allow(clippy::unnecessary_operation, clippy::identity_op)]
+    const _: () = {
+        ["Size of Test"][::std::mem::size_of::<Test>() - 1usize];
+        ["Alignment of Test"][::std::mem::align_of::<Test>() - 1usize];
+    };
 }
