@@ -8,16 +8,12 @@ pub struct S {
 fn bindgen_test_layout_S() {
     const UNINIT: ::std::mem::MaybeUninit<S> = ::std::mem::MaybeUninit::uninit();
     let ptr = UNINIT.as_ptr();
-    assert_eq!(::std::mem::size_of::<S>(), 33usize, concat!("Size of: ", stringify!(S)));
-    assert_eq!(
-        ::std::mem::align_of::<S>(),
-        1usize,
-        concat!("Alignment of ", stringify!(S)),
-    );
+    assert_eq!(::std::mem::size_of::<S>(), 33usize, "Size of S");
+    assert_eq!(::std::mem::align_of::<S>(), 1usize, "Alignment of S");
     assert_eq!(
         unsafe { ::std::ptr::addr_of!((*ptr).large_array) as usize - ptr as usize },
         0usize,
-        concat!("Offset of field: ", stringify!(S), "::", stringify!(large_array)),
+        "Offset of field: S::large_array",
     );
 }
 impl Default for S {
@@ -31,8 +27,8 @@ impl Default for S {
 }
 #[repr(C)]
 pub struct ST<T> {
-    pub large_array: [T; 33usize],
     pub _phantom_0: ::std::marker::PhantomData<::std::cell::UnsafeCell<T>>,
+    pub large_array: [T; 33usize],
 }
 impl<T> Default for ST<T> {
     fn default() -> Self {
