@@ -1,11 +1,11 @@
 #![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
-extern "C" {
+unsafe extern "C" {
     pub fn test_fn(
         a: f32,
         arr: *mut [::std::os::raw::c_int; 20usize],
     ) -> ::std::os::raw::c_int;
 }
-extern "C" {
+unsafe extern "C" {
     pub fn test_fn2(
         arr: *const [f32; 20usize],
         b: ::std::os::raw::c_int,
@@ -13,6 +13,6 @@ extern "C" {
 }
 pub type defArr = [::std::os::raw::c_char; 20usize];
 pub type foo = ::std::option::Option<unsafe extern "C" fn(a: *mut defArr)>;
-extern "C" {
+unsafe extern "C" {
     pub fn bar(a: *mut defArr);
 }
